aboutsummaryrefslogtreecommitdiffstats
path: root/make-version.pl
diff options
context:
space:
mode:
authorGerald Combs <gerald@wireshark.org>2008-05-05 17:03:22 +0000
committerGerald Combs <gerald@wireshark.org>2008-05-05 17:03:22 +0000
commite9a197ee94f77cb156681486a1c0a1edddd9acc0 (patch)
treee9dc1c86ae8462f09f107f8fdaedd90787eeec09 /make-version.pl
parent023a81709a229c819e0b2adee60be74d0d4a1b2a (diff)
Have autoconf generate "ustar" tar files by default. This should let us have
paths longer than 99 characters. svn path=/trunk/; revision=25232
Diffstat (limited to 'make-version.pl')
-rwxr-xr-xmake-version.pl8
1 files changed, 4 insertions, 4 deletions
diff --git a/make-version.pl b/make-version.pl
index 5a47943c43..d851a52854 100755
--- a/make-version.pl
+++ b/make-version.pl
@@ -37,7 +37,7 @@
# pkg_format - Like "format", but used for the package version.
#
# If run with the "-p" or "--package-version" argument, the
# AM_INIT_AUTOMAKE macro in configure.in and the VERSION macro in
# config.nmake will have the pkg_format template appended to the
# version number. svnversion.h will _not_ be generated if either
# argument is present.
@@ -160,7 +160,7 @@ sub read_svn_info {
# Read configure.in, then write it back out with an updated
-# "AM_INIT_AUTOMAKE" line.
+# "AC_INIT" line.
sub update_configure_in
{
my $line;
@@ -171,8 +171,8 @@ sub update_configure_in
open(CFGIN, "< configure.in") || die "Can't read configure.in!";
while ($line = <CFGIN>) {
- if ($line =~ /^AM_INIT_AUTOMAKE\(wireshark, (\d+)\.(\d+).(\d+)/) {
- $line = "AM_INIT_AUTOMAKE\(wireshark, $1.$2.$3$package_string)\n";
+ if ($line =~ /^AC_INIT\(wireshark, (\d+)\.(\d+).(\d+)/) {
+ $line = "AC_INIT\(wireshark, $1.$2.$3$package_string)\n";
}
$contents .= $line
}
@@ -37,7 +37,7 @@
#
# If run with the "-p" or "--package-version" argument, the
-# AM_INIT_AUTOMAKE macro in configure.in and the VERSION macro in
+# AC_INIT macro in configure.in and the VERSION macro in
# config.nmake will have the pkg_format template appended to the
# version number. svnversion.h will _not_ be generated if either